@@ -1,5 +1,5 @@
 """URLs for the test app."""
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django.http import HttpResponse
 from django.views.generic import View
 
